@@ -1,13 +1,16 @@
 #include <R_ext/RS.h>
 #include <stdlib.h> // for NULL
 #include <R_ext/Rdynload.h>
+#include "clogic.h"
 
 /* FIXME: 
    Check these declarations against the C/Fortran source code.
 */
 
 /* .C calls */
+/*
 extern void clogreg(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+*/
 
 static const R_CMethodDef CEntries[] = {
     {"clogreg", (DL_FUNC) &clogreg, 15},
